epi2melabs
==========

The `epi2melabs` python package provides utility functions and scripts for
running in notebook environments.

Installation
------------

`epi2melabs` is easily installed in the standard python tradition:

    git clone --recursive https://github.com/epi2me-labs/epi2melabs.git
    cd epi2melabs
    pip install -r requirements.txt
    python setup.py install

or via pip:

    pip install epi2melabs.
